fix collapsing problem with templates (templates would be expanded and
[lhc/web/wiklou.git] / index.php
index 66a5845..d2ec9fc 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,24 +1,18 @@
 <?php
+
 # Main wiki script; see design.doc
 #
 $wgRequestTime = microtime();
 
 unset( $IP );
-ini_set( "allow_url_fopen", 0 ); # For security...
+@ini_set( "allow_url_fopen", 0 ); # For security...
 if(!file_exists("LocalSettings.php")) {
        die( "You'll have to <a href='config/index.php'>set the wiki up</a> first!" );
 }
-include_once( "./LocalSettings.php" );
-
-if( $wgSitename == "MediaWiki" ) {
-       die( "You must set the site name in \$wgSitename before installation.\n\n" );
-}
-
-# PATH_SEPARATOR avaialble only from 4.3.0
-$sep = (DIRECTORY_SEPARATOR == "\\") ? ";" : ":";
-ini_set( "include_path", $IP . $sep . ini_get( "include_path" ) );
 
-include_once( "Setup.php" );
+define( "MEDIAWIKI", true );
+require_once( "./LocalSettings.php" );
+require_once( "includes/Setup.php" );
 
 wfProfileIn( "main-misc-setup" );
 OutputPage::setEncodings(); # Not really used yet
@@ -26,7 +20,7 @@ OutputPage::setEncodings(); # Not really used yet
 # Query string fields
 $action = $wgRequest->getVal( "action", "view" );
 
-if( isset( $_SERVER['PATH_INFO'] ) ) {
+if( isset( $_SERVER['PATH_INFO'] ) && $wgUsePathInfo ) {
        $title = substr( $_SERVER['PATH_INFO'], 1 );
 } else {
        $title = $wgRequest->getVal( "title" );
@@ -37,7 +31,6 @@ $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
 $wgArticle = new Article($wgTitle);
 
 $action = strtolower( trim( $action ) );
-if ( "" == $action ) { $action = "view"; }
 if ($wgRequest->getVal( "printable" ) == "yes") {
        $wgOut->setPrintable();
 }
@@ -52,25 +45,34 @@ if ( "" == $title && "delete" != $action ) {
 }
 wfProfileOut( "main-misc-setup" );
 
-# If the user is not logged in, the Namespace:title of the article must be in the Read array in
-#  order for the user to see it.
-if ( !$wgUser->getID() && is_array( $wgWhitelistRead ) && $wgTitle) {
-       if ( !in_array( $wgLang->getNsText( $wgTitle->getNamespace() ) . ":" . $wgTitle->getDBkey(), $wgWhitelistRead ) ) {
-               $wgOut->loginToUse();
-               $wgOut->output();
-               exit;
-       }
+# If the user is not logged in, the Namespace:title of the article must be in
+# the Read array in order for the user to see it. (We have to check here to
+# catch special pages etc. We check again in Article::view())
+if ( !$wgTitle->userCanRead() ) {
+       $wgOut->loginToUse();
+       $wgOut->output();
+       exit;
 }
 
 if ( $search = $wgRequest->getText( 'search' ) ) {
+       $wgTitle = Title::makeTitle( NS_SPECIAL, "Search" );
        if( $wgRequest->getVal( 'fulltext' ) ) {
                wfSearch( $search );
        } else {
                wfGo( $search );
        }
-} else if( !$wgTitle or $wgTitle->getInterwiki() != "" or $wgTitle->getDBkey() == "" ) {
+} else if( !$wgTitle or $wgTitle->getDBkey() == "" ) {
        $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
        $wgOut->errorpage( "badtitle", "badtitletext" );
+} else if ( $wgTitle->getInterwiki() != "" ) {
+       $url = $wgTitle->getFullURL();
+       # Check for a redirect loop
+       if ( !preg_match( "/^" . preg_quote( $wgServer ) . "/", $url ) && $wgTitle->isLocal() ) {
+               $wgOut->redirect( $url );
+       } else {
+               $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
+               $wgOut->errorpage( "badtitle", "badtitletext" );
+       }
 } else if ( ( $action == "view" ) && $wgTitle->getPrefixedDBKey() != $title ) {
        /* redirect to canonical url, make it a 301 to allow caching */
        $wgOut->redirect( $wgTitle->getFullURL(), '301');
@@ -80,10 +82,10 @@ if ( $search = $wgRequest->getText( 'search' ) ) {
        if ( Namespace::getMedia() == $wgTitle->getNamespace() ) {
                $wgTitle = Title::makeTitle( Namespace::getImage(), $wgTitle->getDBkey() );
        }
-       
+
        switch( $wgTitle->getNamespace() ) {
        case NS_IMAGE:
-               include_once( "ImagePage.php" );
+               require_once( "includes/ImagePage.php" );
                $wgArticle = new ImagePage( $wgTitle );
                break;
        default:
@@ -94,7 +96,7 @@ if ( $search = $wgRequest->getText( 'search' ) ) {
        switch( $action ) {
                case "view":
                        $wgOut->setSquidMaxage( $wgSquidMaxage );
-                       $wgArticle->$action();
+                       $wgArticle->view();
                        break;
                case "watch":
                case "unwatch":
@@ -108,12 +110,28 @@ if ( $search = $wgRequest->getText( 'search' ) ) {
                case "print":
                        $wgArticle->view();
                        break;
+               case "dublincore":
+                       if( !$wgEnableDublinCoreRdf ) {
+                               wfHttpError( 403, "Forbidden", wfMsg( "nodublincore" ) );
+                       } else {
+                               require_once( "includes/Metadata.php" );
+                               wfDublinCoreRdf( $wgArticle );
+                       }
+                       break;
+               case "creativecommons":
+                       if( !$wgEnableCreativeCommonsRdf ) {
+                               wfHttpError( 403, "Forbidden", wfMsg("nocreativecommons") );
+                       } else {
+                               require_once( "includes/Metadata.php" );
+                               wfCreativeCommonsRdf( $wgArticle );
+                       }
+                       break;
                case "edit":
                case "submit":
                        if( !$wgCommandLineMode && !$wgRequest->checkSessionCookie() ) {
                                User::SetupSession();
                        }
-                       include_once( "EditPage.php" );
+                       require_once( "includes/EditPage.php" );
                        $editor = new EditPage( $wgArticle );
                        $editor->$action();
                        break;
@@ -121,10 +139,15 @@ if ( $search = $wgRequest->getText( 'search' ) ) {
                        if ($_SERVER["REQUEST_URI"] == $wgTitle->getInternalURL('action=history')) {
                                $wgOut->setSquidMaxage( $wgSquidMaxage );
                        }
-                       include_once( "PageHistory.php" );
+                       require_once( "includes/PageHistory.php" );
                        $history = new PageHistory( $wgArticle );
                        $history->history();
                        break;
+               case "raw":
+                       require_once( "includes/RawPage.php" );
+                       $raw = new RawPage( $wgArticle );
+                       $raw->view();
+                       break;
                case "purge":
                        wfPurgeSquidServers(array($wgTitle->getInternalURL()));
                        $wgOut->setSquidMaxage( $wgSquidMaxage );